@@ -1,7 +1,7 @@
 package Progress::Any;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2018-03-16'; # DATE
+our $VERSION = '0.210'; # VERSION
 
 use 5.010001;
 use strict;
@@ -403,6 +403,7 @@ sub update {
 
     # find output(s) and call it
     {
+        last unless $ENV{PROGRESS} // 1;
         my $task = $self->{task};
         while (1) {
             if ($outputs{$task}) {
@@ -563,10 +564,28 @@ Progress::Any - Record progress to any output
 
 =head1 VERSION
 
-This document describes version 0.19 of Progress::Any (from Perl distribution Progress-Any), released on 2015-01-22.
+This document describes version 0.210 of Progress::Any (from Perl distribution Progress-Any), released on 2018-03-16.
 
 =head1 SYNOPSIS
 
+=head2 First example, simple usage in a script
+
+ use Progress::Any '$progress';
+ use Progress::Any::Output 'TermProgressBarColor';
+
+ $progress->target(10);
+ for (1..10) {
+     $progress->update(message => "Doing item $_");
+     sleep 1;
+ }
+
+Sample output:
+
+ % ./script.pl
+  60% [Doing item 6====           ]3s left
+
+=head2 Second example, usage in module as well as script
+
 In your module:
 
  package MyApp;
@@ -592,8 +611,9 @@ In your application:
 
  MyApp::download("url1", "url2", "url3", "url4", "url5");
 
-When run, your application will display something like this, in succession:
+sample output, in succession:
 
+ % ./script.pl
   20% [====== Downloaded url1           ]0m00s Left
   40% [=======Downloaded url2           ]0m01s Left
   60% [=======Downloaded url3           ]0m01s Left
@@ -601,7 +621,7 @@ When run, your application will display something like this, in succession:
 
 (At 100%, the output automatically cleans up the progress bar).
 
-Another example, demonstrating multiple indicators and the LogAny output:
+=head2 Another example, demonstrating multiple indicators and the LogAny output:
 
  use Progress::Any;
  use Progress::Any::Output;
@@ -625,6 +645,8 @@ will show something like:
  [download] [2/10] downloading B
  [copy    ] [2/ ?] copying B
 
+=head2 Example of using with Perinci::CmdLine
+
 If you use L<Perinci::CmdLine>, you can mark your function as expecting a
 Progress::Any object and it will be supplied to you in a special argument
 C<-progress>:
@@ -953,15 +975,11 @@ A literal C<%> sign.
 
 =head1 FAQ
 
-=head1 SEE ALSO
+=head1 ENVIRONMENT
 
-Other progress modules on CPAN: L<Term::ProgressBar>,
-L<Term::ProgressBar::Simple>, L<Time::Progress>, among others.
+=head2 PROGRESS
 
-Output modules: C<Progress::Any::Output::*>
-
-See examples on how Progress::Any is used by other modules: L<Perinci::CmdLine>
-(supplying progress object to functions), L<Git::Bunch> (using progress object).
+Boolean. Default 1. Can be set to 0 to display progress output.
 
 =head1 HOMEPAGE
 
@@ -979,13 +997,23 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Other progress modules on CPAN: L<Term::ProgressBar>,
+L<Term::ProgressBar::Simple>, L<Time::Progress>, among others.
+
+Output modules: C<Progress::Any::Output::*>
+
+See examples on how Progress::Any is used by other modules: L<Perinci::CmdLine>
+(supplying progress object to functions), L<Git::Bunch> (using progress object).
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
